@@ -5,9 +5,12 @@ from FLog.LOGGER import Log
 Log = Log("FairWeb.Core.Soup.Parse()")
 
 # -> Step Two -> Convert Response Object to HTML Object
-def to_html(response):
+def to_html_from_response(response):
     return BeautifulSoup(response.text, 'html.parser')
 
+def to_html_from_text(text):
+    return BeautifulSoup(text, 'html.parser')
+
 def safe_find(tag, term):
     try:
         return tag.find(term)
@@ -24,6 +27,7 @@ class Parse:
     response = None
     status = False
     soup = None
+    raw_text = None
     tag_body: bsTag = None
     tag_head: bsTag = None
     tag_time: bsTag = None
@@ -33,9 +37,13 @@ class Parse:
     element_meta = None
     element_span = None
 
-    def __init__(self, response):
+    def __init__(self, response=None, rawText=None):
         self.response = response
-        if self.to_html():
+        self.raw_text = rawText
+        if rawText:
+            if self.to_html_from_raw_text():
+                self.extract_elements_and_tags()
+        elif self.to_html():
             self.extract_elements_and_tags()
 
     # -> Step Two -> Convert Response Object to HTML Object
@@ -46,6 +54,13 @@ class Parse:
         else:
             return False
 
+    def to_html_from_raw_text(self):
+        if self.raw_text:
+            self.soup = BeautifulSoup(self.raw_text, 'html.parser')
+            return True
+        else:
+            return False
+
     # -> Step Three -> Convert HTML into Element/Tag Objects
     def extract_elements_and_tags(self):
         Log.i(f"Extracting HTML Elements.")
@@ -73,11 +88,4 @@ class Parse:
         #         print(keywords)
         # test_attr = Tag.get_attribute(test_tag, "datetime")
         # print(test_attr)
-        pass
-
-if __name__ == '__main__':
-    test1 = "https://public.totalglobalsports.com/public/event/2038/game-complex/466/1653/35242"
-    test = "https://public.totalglobalsports.com/public/event/2038/individual-team/18/35266/9"
-    s = Parse(test1)
-    result = Tag.search_tag_deep(s.tag_body, "tbody", enableName=True)
-    print(result)
\ No newline at end of file
+        pass
\ No newline at end of file
